@@ -19,19 +19,6 @@ gdk_dmabuf_downloader_close (GdkDmabufDownloader *self)
 }
 
 gboolean
-gdk_dmabuf_downloader_supports (GdkDmabufDownloader  *self,
-                                GdkDmabufTexture     *texture,
-                                GError              **error)
-{
-  GdkDmabufDownloaderInterface *iface;
-
-  g_return_val_if_fail (GDK_IS_DMABUF_DOWNLOADER (self), FALSE);
-
-  iface = GDK_DMABUF_DOWNLOADER_GET_IFACE (self);
-  return iface->supports (self, texture, error);
-}
-
-void
 gdk_dmabuf_downloader_download (GdkDmabufDownloader *self,
                                 GdkDmabufTexture    *texture,
                                 GdkMemoryFormat      format,
@@ -41,9 +28,8 @@ gdk_dmabuf_downloader_download (GdkDmabufDownloader *self,
 {
   GdkDmabufDownloaderInterface *iface;
 
-  g_return_if_fail (GDK_IS_DMABUF_DOWNLOADER (self));
+  g_return_val_if_fail (GDK_IS_DMABUF_DOWNLOADER (self), FALSE);
 
   iface = GDK_DMABUF_DOWNLOADER_GET_IFACE (self);
-  iface->download (self, texture, format, color_state, data, stride);
+  return iface->download (self, texture, format, color_state, data, stride);
 }
-
