@@ -177,7 +177,8 @@ gsk_vulkan_image_create_view (GskVulkanImage            *self,
                                      .image = self->vk_image,
                                      .viewType = VK_IMAGE_VIEW_TYPE_2D,
                                      .format = vk_format,
-                                     .components = *vk_components,
+                                     .components = vk_conversion ? (VkComponentMapping) { 0, }
+                                                                 : *vk_components,
                                      .subresourceRange = {
                                          .aspectMask = VK_IMAGE_ASPECT_COLOR_BIT,
                                          .baseMipLevel = 0,
@@ -343,10 +344,10 @@ gsk_vulkan_image_new (GskVulkanDevice           *device,
   if (gdk_memory_format_alpha (format) == GDK_MEMORY_ALPHA_STRAIGHT)
     flags |= GSK_GPU_IMAGE_STRAIGHT_ALPHA;
 
-  if (((flags & (GSK_GPU_IMAGE_FILTERABLE | GSK_GPU_IMAGE_RENDERABLE | GSK_GPU_IMAGE_NO_BLIT | GSK_GPU_IMAGE_STRAIGHT_ALPHA)) ==
-       (GSK_GPU_IMAGE_FILTERABLE | GSK_GPU_IMAGE_RENDERABLE)) &&
-      (required_flags & GSK_GPU_IMAGE_CAN_MIPMAP))
-    flags |= GSK_GPU_IMAGE_CAN_MIPMAP;
+  if (((flags & (GSK_GPU_IMAGE_FILTERABLE | GSK_GPU_IMAGE_RENDERABLE | GSK_GPU_IMAGE_NO_BLIT | GSK_GPU_IMAGE_CAN_MIPMAP | GSK_GPU_IMAGE_STRAIGHT_ALPHA)) !=
+       (GSK_GPU_IMAGE_FILTERABLE | GSK_GPU_IMAGE_RENDERABLE | GSK_GPU_IMAGE_CAN_MIPMAP)) ||
+      !(required_flags & GSK_GPU_IMAGE_CAN_MIPMAP))
+    flags &= ~GSK_GPU_IMAGE_CAN_MIPMAP;
 
   if (!gsk_component_mapping_is_framebuffer_compatible (&vk_components))
     flags |= GSK_GPU_IMAGE_NO_BLIT;
@@ -683,7 +684,8 @@ gsk_vulkan_image_new_dmabuf (GskVulkanDevice *device,
   gsize n_modifiers;
   GskGpuImageFlags flags;
 
-  if (!gsk_vulkan_device_has_feature (device, GDK_VULKAN_FEATURE_DMABUF))
+  if (!gdk_has_feature (GDK_FEATURE_DMABUF) ||
+      !gsk_vulkan_device_has_feature (device, GDK_VULKAN_FEATURE_DMABUF))
     return NULL;
 
   vk_srgb_format = VK_FORMAT_UNDEFINED;
